@@ -7,6 +7,7 @@
 #include "command.h"
 #include "db.h"
 #include "leader.h"
+#include "lib/assert.h"
 #include "lib/queue.h"
 #include "lib/sm.h"
 #include "raft.h"
@@ -14,7 +15,7 @@
 #include "utils.h"
 #include "vfs.h"
 
-#define leader_trace(L, fmt, ...) tracef("[leader %p] "fmt, L, ##__VA_ARGS__)
+#define leader_trace(L, fmt, ...) tracef("[leader %p] "fmt, (void*)L, ##__VA_ARGS__)
 
 static bool exec_invariant(const struct sm *sm, int prev);
 static void exec_tick(struct exec *req);
@@ -92,7 +93,7 @@ static struct exec *leader_finalize(struct leader *leader)
 
 	sqlite3_progress_handler(leader->conn, 1, progress_abort, NULL);
 	int rc = sqlite3_close_v2(leader->conn);
-	assert(rc == 0);
+	dqlite_assert(rc == 0);
 
 	leader->close_cb(leader);
 
@@ -468,7 +469,7 @@ static void exec_tick(struct exec *req)
 
 			if (IN(db->active_leader, NULL, leader)) {
 				db->active_leader = leader;
-				leader_trace(leader, "active leader = %p", leader);
+				leader_trace(leader, "active leader = %p", (void*)leader);
 				sm_move(&req->sm, EXEC_WAITING_QUEUE);
 				continue;
 			}
@@ -538,7 +539,7 @@ static void exec_tick(struct exec *req)
 				}
 
 				leader_trace(leader,
-					     "polled connection (%d frames)",
+					     "polled connection (%" PRIu32 " frames)",
 					     transaction.n_pages);
 				if (transaction.n_pages == 0) {
 					sm_move(&req->sm, EXEC_DONE);
@@ -562,7 +563,7 @@ static void exec_tick(struct exec *req)
 		case EXEC_WAITING_APPLY:
 			if (req->status != RAFT_OK) {
 				int rv = VfsAbort(leader->conn);
-				assert(rv == SQLITE_OK);
+				dqlite_assert(rv == SQLITE_OK);
 			}
 			sm_move(&req->sm, EXEC_DONE);
 			continue;
