@@ -10,6 +10,7 @@
 #define CHECK(cond) sm_check((cond), __FILE__, __LINE__, #cond)
 
 #define SM_MAX_NAME_LENGTH 50
+#define SM_MAX_ATTR_LENGTH 100
 
 enum {
 	SM_PREV_NONE = -1,
@@ -50,9 +51,14 @@ void sm_init(struct sm *m,
 void sm_fini(struct sm *m);
 void sm_move(struct sm *m, int next_state);
 void sm_fail(struct sm *m, int fail_state, int rc);
+void sm_done(struct sm *m, int good_state, int bad_state, int rc);
 int sm_state(const struct sm *m);
 bool sm_check(bool b, const char *f, int n, const char *s);
 /* Relates one state machine to another for observability. */
 void sm_relate(const struct sm *from, const struct sm *to);
+/**
+ * Records an attribute of a state machine for observability.
+ */
+void sm_attr(const struct sm *m, const char *k, const char *fmt, ...);
 
 #endif /* __LIB_SM__ */
