@@ -81,7 +81,7 @@ enum {
 	DQLITE_RESPONSE_ROWS,
 	DQLITE_RESPONSE_EMPTY,
 	DQLITE_RESPONSE_FILES,
-	DQLITE_RESPONSE_METADATA
+	DQLITE_RESPONSE_METADATA,
 };
 
 #endif /* DQLITE_PROTOCOL_H_ */
