@@ -1,7 +1,7 @@
 #include "recv_request_vote.h"
 
+#include "../lib/assert.h"
 #include "../tracing.h"
-#include "assert.h"
 #include "election.h"
 #include "recv.h"
 #include "replication.h"
@@ -24,14 +24,13 @@ int recvRequestVote(struct raft *r,
 	int match;
 	int rv;
 
-	assert(r != NULL);
-	assert(id > 0);
-	assert(args != NULL);
+	dqlite_assert(r != NULL);
+	dqlite_assert(id > 0);
+	dqlite_assert(args != NULL);
 
 	tracef(
-	    "self:%llu from:%llu@%s candidate_id:%llu disrupt_leader:%d "
-	    "last_log_index:%llu "
-	    "last_log_term:%llu pre_vote:%d term:%llu",
+	    "self: %" PRIu64 " from: %" PRIu64 "@%s candidate_id: %" PRIu64 " disrupt_leader: %d "
+	    "last_log_index: %" PRIu64 " last_log_term: %" PRIu64 " pre_vote: %d term: %" PRIu64,
 	    r->id, id, address, args->candidate_id, args->disrupt_leader,
 	    args->last_log_index, args->last_log_term, args->pre_vote,
 	    args->term);
@@ -104,9 +103,9 @@ int recvRequestVote(struct raft *r,
 	 * same as the request term (otherwise we would have rejected the
 	 * request or bumped our term). */
 	if (!args->pre_vote) {
-		tracef("no pre_vote: current_term:%llu term:%llu",
+		tracef("no pre_vote: current_term: %" PRIu64 " term: %" PRIu64,
 		       r->current_term, args->term);
-		assert(r->current_term == args->term);
+		dqlite_assert(r->current_term == args->term);
 	}
 
 	rv = electionVote(r, args, &result->vote_granted);
