@@ -15,7 +15,7 @@
 
 /* Template string for closed segment filenames: start index (inclusive), end
  * index (inclusive). */
-#define UV__CLOSED_TEMPLATE "%016llu-%016llu"
+#define UV__CLOSED_TEMPLATE "%016" PRIu64 "-%016" PRIu64
 
 /* Template string for open segment filenames: incrementing counter. */
 #define UV__OPEN_TEMPLATE "open-%llu"
@@ -25,7 +25,7 @@
 
 /* Template string for snapshot filenames: snapshot term, snapshot index,
  * creation timestamp (milliseconds since epoch). */
-#define UV__SNAPSHOT_TEMPLATE "snapshot-%llu-%llu-%llu"
+#define UV__SNAPSHOT_TEMPLATE "snapshot-%" PRIu64 "-%" PRIu64 "-%" PRIu64
 
 #define UV__SNAPSHOT_META_SUFFIX ".meta"
 
@@ -109,7 +109,7 @@ int uvMetadataLoad(const char *dir, struct uvMetadata *metadata, char *errmsg);
 /* Store the given metadata to disk, writing the appropriate metadata file
  * according to the metadata version (if the version is odd, write metadata1,
  * otherwise write metadata2). */
-int uvMetadataStore(struct uv *uv, const struct uvMetadata *metadata);
+int uvMetadataStore(const char *dir, const struct uvMetadata *metadata, char *errmsg);
 
 /* Metadata about a segment file. */
 struct uvSegmentInfo
@@ -153,6 +153,13 @@ int uvSegmentKeepTrailing(struct uv *uv,
 			  size_t trailing,
 			  char *errmsg);
 
+/* Load all entries contained in an open segment. */
+int uvSegmentLoadOpen(struct uv *uv,
+			     struct uvSegmentInfo *info,
+			     struct raft_entry *entries[],
+			     size_t *n,
+			     raft_index *next_index);
+
 /* Load all entries contained in the given closed segment. */
 int uvSegmentLoadClosed(struct uv *uv,
 			struct uvSegmentInfo *segment,
@@ -234,7 +241,7 @@ struct uvSnapshotInfo
 {
 	raft_term term;
 	raft_index index;
-	unsigned long long timestamp;
+	raft_time timestamp;
 	char filename[UV__FILENAME_LEN];
 };
 
@@ -252,7 +259,7 @@ int UvSnapshotMetaIsOrphan(const char *dir, const char *filename, bool *orphan);
 /* Append a new item to the given snapshot info list if the given filename
  * matches the pattern of a snapshot metadata file (snapshot-xxx-yyy-zzz.meta)
  * and there is actually a matching non-empty snapshot file on disk. */
-int UvSnapshotInfoAppendIfMatch(struct uv *uv,
+int UvSnapshotInfoAppendIfMatch(const char *dir,
 				const char *filename,
 				struct uvSnapshotInfo *infos[],
 				size_t *n_infos,
@@ -288,7 +295,7 @@ int UvAsyncWork(struct raft_io *io,
 /* Return a list of all snapshots and segments found in the data directory. Both
  * snapshots and segments are ordered by filename (closed segments come before
  * open ones). */
-int UvList(struct uv *uv,
+int UvList(const char* dir,
 	   struct uvSnapshotInfo *snapshots[],
 	   size_t *n_snapshots,
 	   struct uvSegmentInfo *segments[],
