@@ -70,7 +70,7 @@ struct value
 	int type;
 	union {
 		int64_t integer;
-		double float_;
+		double real;
 		uv_buf_t blob;
 		uint64_t null;
 		const char *text;
@@ -114,6 +114,12 @@ int tuple_decoder__init(struct tuple_decoder *d,
  */
 unsigned long tuple_decoder__n(struct tuple_decoder *d);
 
+/**
+ * Returns the number of values remaining to be decoded.
+ *
+ */
+unsigned long tuple_decoder__remaining(struct tuple_decoder *d);
+
 /**
  * Decode the next value of the tuple.
  */
