@@ -71,8 +71,6 @@ static void tearDown(void *data)
 	free(f);
 }
 
-static char *bools[] = { "0", "1", NULL };
-
 static char *num_records[] = {
 	"0", "1", "256",
 	/* WAL will just have been checkpointed after 993 writes. */
@@ -83,7 +81,6 @@ static char *num_records[] = {
 
 static MunitParameterEnum cluster_params[] = {
 	{ "num_records", num_records },
-	{ "disk_mode", bools },
 	{ NULL, NULL },
 };
 
@@ -208,9 +205,8 @@ TEST(cluster, dataOnNewNode, setUp, tearDown, 0, cluster_params)
 	return MUNIT_OK;
 }
 
-/* Insert a huge row, causing SQLite to allocate overflow pages. Then
- * insert the same row again. (Reproducer for
- * https://github.com/canonical/raft/issues/432.) */
+/* Insert a huge row, causing SQLite to allocate overflow pages and additional
+ * shm regions. Then insert the same row again. */
 TEST(cluster, hugeRow, setUp, tearDown, 0, NULL)
 {
 	struct fixture *f = data;
@@ -243,6 +239,46 @@ TEST(cluster, hugeRow, setUp, tearDown, 0, NULL)
 	return MUNIT_OK;
 }
 
+/* Insert a huge row, causing SQLite to allocate overflow pages and additional
+ * shm regions. Then insert the same row again.
+ * Then rollback so that the rollback logic spawning multiple regions is
+ * exercised. */
+TEST(cluster, hugeRow_rollback, setUp, tearDown, 0, NULL)
+{
+	struct fixture *f = data;
+	uint32_t stmt_id;
+	uint64_t last_insert_id;
+	uint64_t rows_affected;
+	char *sql;
+	ssize_t n;
+	size_t huge = 20000000;
+	(void)params;
+
+	HANDSHAKE;
+	OPEN;
+	PREPARE(
+	    "CREATE TABLE IF NOT EXISTS model(key TEXT, value TEXT, "
+	    "UNIQUE(key))",
+	    &stmt_id);
+	EXEC(stmt_id, &last_insert_id, &rows_affected);
+	sql = munit_malloc(huge);
+	n = snprintf(
+	    sql, huge,
+	    "INSERT OR REPLACE INTO model (key, value) VALUES('my-key-1', '");
+	memset(sql + n, 'A', huge - n);
+	memcpy(sql + huge - 3, "')", 3);
+	PREPARE(sql, &stmt_id);
+	free(sql);
+
+	EXEC_SQL("BEGIN IMMEDIATE;", &last_insert_id, &rows_affected);
+	EXEC(stmt_id, &last_insert_id, &rows_affected);
+	/* Again */
+	EXEC(stmt_id, &last_insert_id, &rows_affected);
+	EXEC_SQL("ROLLBACK;", &last_insert_id, &rows_affected);
+
+	return MUNIT_OK;
+}
+
 TEST(cluster, modifyingQuery, setUp, tearDown, 0, cluster_params)
 {
 	struct fixture *f = data;
