@@ -58,7 +58,6 @@ static char *snapshot_threshold[] = {"8192", NULL};
 static MunitParameterEnum snapshot_params[] = {
     {SNAPSHOT_THRESHOLD_PARAM, snapshot_threshold},
     {SNAPSHOT_COMPRESSION_PARAM, bools},
-    {"disk_mode", bools},
     {NULL, NULL},
 };
 
@@ -97,25 +96,12 @@ TEST(fsm, snapshotFreshDb, setUp, tearDown, 0, snapshot_params)
 	unsigned n_bufs = 0;
 	int rv;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
 	munit_assert_int(rv, ==, 0);
 	munit_assert_uint(n_bufs, ==, 1); /* Snapshot header */
 
-	if (disk_mode) {
-		rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, ==, 0);
-	}
-
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
+	rv = fsm->snapshot_finalize(fsm, bufs, n_bufs);
 	munit_assert_int(rv, ==, 0);
-	munit_assert_ptr_null(bufs);
-	munit_assert_uint(n_bufs, ==, 0);
 	return MUNIT_OK;
 }
 
@@ -131,12 +117,6 @@ TEST(fsm, snapshotWrittenDb, setUp, tearDown, 0, snapshot_params)
 	uint64_t last_insert_id;
 	uint64_t rows_affected;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Add some data to database */
 	HANDSHAKE;
 	OPEN;
@@ -149,15 +129,8 @@ TEST(fsm, snapshotWrittenDb, setUp, tearDown, 0, snapshot_params)
 	munit_assert_int(rv, ==, 0);
 	munit_assert_uint(n_bufs, >, 1);
 
-	if (disk_mode) {
-		rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, ==, 0);
-	}
-
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
+	rv = fsm->snapshot_finalize(fsm, bufs, n_bufs);
 	munit_assert_int(rv, ==, 0);
-	munit_assert_ptr_null(bufs);
-	munit_assert_uint(n_bufs, ==, 0);
 	return MUNIT_OK;
 }
 
@@ -173,12 +146,6 @@ TEST(fsm, snapshotHeapFaultSingleDB, setUp, tearDown, 0, snapshot_params)
 	uint64_t last_insert_id;
 	uint64_t rows_affected;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Add some data to database */
 	HANDSHAKE;
 	OPEN;
@@ -201,66 +168,6 @@ TEST(fsm, snapshotHeapFaultSingleDB, setUp, tearDown, 0, snapshot_params)
 	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
 	munit_assert_int(rv, !=, 0);
 
-	/* disk_mode does fewer allocations */
-	if (!disk_mode) {
-		test_heap_fault_config(2, 1);
-		rv = fsm->snapshot(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, !=, 0);
-	}
-
-	return MUNIT_OK;
-}
-
-/* Inject faults into the async stage of the snapshot process */
-TEST(fsm,
-     snapshotHeapFaultSingleDBAsyncDisk,
-     setUp,
-     tearDown,
-     0,
-     snapshot_params)
-{
-	struct fixture *f = data;
-	struct raft_fsm *fsm = &f->servers[0].dqlite->raft_fsm;
-	struct raft_buffer *bufs;
-	unsigned n_bufs = 0;
-	int rv;
-
-	uint32_t stmt_id;
-	uint64_t last_insert_id;
-	uint64_t rows_affected;
-
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
-	if (!disk_mode) {
-		return MUNIT_SKIP;
-	}
-
-	/* Add some data to database */
-	HANDSHAKE;
-	OPEN;
-	PREPARE("CREATE TABLE test (n INT)", &stmt_id);
-	EXEC(stmt_id, &last_insert_id, &rows_affected);
-	PREPARE("INSERT INTO test(n) VALUES(1)", &stmt_id);
-	EXEC(stmt_id, &last_insert_id, &rows_affected);
-
-	/* Sync stage succeeds */
-	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, ==, 0);
-
-	/* Inject heap fault in first call to encodeDiskDatabaseAsync */
-	test_heap_fault_config(0, 1);
-	test_heap_fault_enable();
-	rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, !=, 0);
-
-	/* Cleanup should succeed */
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, ==, 0);
-
 	return MUNIT_OK;
 }
 
@@ -276,12 +183,6 @@ TEST(fsm, snapshotHeapFaultTwoDB, setUp, tearDown, 0, snapshot_params)
 	uint64_t last_insert_id;
 	uint64_t rows_affected;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Open 2 databases and add data to them */
 	HANDSHAKE;
 	OPEN_NAME("test");
@@ -318,87 +219,6 @@ TEST(fsm, snapshotHeapFaultTwoDB, setUp, tearDown, 0, snapshot_params)
 	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
 	munit_assert_int(rv, !=, 0);
 
-	/* disk_mode does fewer allocations */
-	if (!disk_mode) {
-		test_heap_fault_config(2, 1);
-		rv = fsm->snapshot(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, !=, 0);
-
-		test_heap_fault_config(3, 1);
-		rv = fsm->snapshot(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, !=, 0);
-	}
-
-	return MUNIT_OK;
-}
-
-TEST(fsm, snapshotHeapFaultTwoDBAsync, setUp, tearDown, 0, snapshot_params)
-{
-	struct fixture *f = data;
-	struct raft_fsm *fsm = &f->servers[0].dqlite->raft_fsm;
-	struct raft_buffer *bufs;
-	unsigned n_bufs = 0;
-	int rv;
-
-	uint32_t stmt_id;
-	uint64_t last_insert_id;
-	uint64_t rows_affected;
-
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
-	if (!disk_mode) {
-		return MUNIT_SKIP;
-	}
-
-	/* Open 2 databases and add data to them */
-	HANDSHAKE;
-	OPEN_NAME("test");
-	PREPARE("CREATE TABLE test (n INT)", &stmt_id);
-	EXEC(stmt_id, &last_insert_id, &rows_affected);
-	PREPARE("INSERT INTO test(n) VALUES(1)", &stmt_id);
-	EXEC(stmt_id, &last_insert_id, &rows_affected);
-
-	/* Close and reopen the client and open a second database */
-	test_server_client_reconnect(&f->servers[0], &f->servers[0].client);
-
-	HANDSHAKE;
-	OPEN_NAME("test2");
-	PREPARE("CREATE TABLE test (n INT)", &stmt_id);
-	EXEC(stmt_id, &last_insert_id, &rows_affected);
-	PREPARE("INSERT INTO test(n) VALUES(1)", &stmt_id);
-	EXEC(stmt_id, &last_insert_id, &rows_affected);
-
-	/* sync fsm__snapshot succeeds. */
-	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, ==, 0);
-
-	/* async step fails at different stages. */
-	test_heap_fault_enable();
-
-	test_heap_fault_config(0, 1);
-	rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, !=, 0);
-
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, ==, 0);
-
-	/* Inject fault when encoding second Database */
-
-	/* sync fsm__snapshot succeeds. */
-	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, ==, 0);
-
-	test_heap_fault_config(1, 1);
-	rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, !=, 0);
-
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
-	munit_assert_int(rv, ==, 0);
-
 	return MUNIT_OK;
 }
 
@@ -414,12 +234,6 @@ TEST(fsm, snapshotNewDbAddedBeforeFinalize, setUp, tearDown, 0, snapshot_params)
 	uint64_t last_insert_id;
 	uint64_t rows_affected;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Add some data to database */
 	HANDSHAKE;
 	OPEN_NAME("test");
@@ -441,18 +255,11 @@ TEST(fsm, snapshotNewDbAddedBeforeFinalize, setUp, tearDown, 0, snapshot_params)
 	PREPARE("CREATE TABLE test (n INT)", &stmt_id);
 	EXEC(stmt_id, &last_insert_id, &rows_affected);
 
-	if (disk_mode) {
-		rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, ==, 0);
-	}
-
 	PREPARE("INSERT INTO test(n) VALUES(1)", &stmt_id);
 	EXEC(stmt_id, &last_insert_id, &rows_affected);
 
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
+	rv = fsm->snapshot_finalize(fsm, bufs, n_bufs);
 	munit_assert_int(rv, ==, 0);
-	munit_assert_ptr_null(bufs);
-	munit_assert_uint(n_bufs, ==, 0);
 	return MUNIT_OK;
 }
 
@@ -468,12 +275,6 @@ TEST(fsm, snapshotWritesBeforeFinalize, setUp, tearDown, 0, snapshot_params)
 	char sql[128];
 	int rv;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Add some data to database */
 	HANDSHAKE;
 	OPEN;
@@ -491,17 +292,11 @@ TEST(fsm, snapshotWritesBeforeFinalize, setUp, tearDown, 0, snapshot_params)
 		sprintf(sql, "INSERT INTO test(n) VALUES(%d)", i + 1);
 		PREPARE(sql, &stmt_id);
 		EXEC(stmt_id, &last_insert_id, &rows_affected);
-		if (disk_mode && i == 512) {
-			rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-			munit_assert_int(rv, ==, 0);
-		}
 	}
 
 	/* Finalize succeeds */
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
+	rv = fsm->snapshot_finalize(fsm, bufs, n_bufs);
 	munit_assert_int(rv, ==, 0);
-	munit_assert_ptr_null(bufs);
-	munit_assert_uint(n_bufs, ==, 0);
 
 	/* Triggers a checkpoint */
 	PREPARE("INSERT INTO test(n) VALUES(1001)", &stmt_id);
@@ -523,12 +318,6 @@ TEST(fsm, concurrentSnapshots, setUp, tearDown, 0, snapshot_params)
 	uint64_t rows_affected;
 	int rv;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Add some data to database */
 	HANDSHAKE;
 	OPEN;
@@ -541,23 +330,14 @@ TEST(fsm, concurrentSnapshots, setUp, tearDown, 0, snapshot_params)
 	rv = fsm->snapshot(fsm, &bufs2, &n_bufs2);
 	munit_assert_int(rv, ==, RAFT_BUSY);
 
-	if (disk_mode) {
-		rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, ==, 0);
-	}
-
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
+	rv = fsm->snapshot_finalize(fsm, bufs, n_bufs);
 	munit_assert_int(rv, ==, 0);
 
 	/* Second snapshot succeeds after first is finalized */
 	rv = fsm->snapshot(fsm, &bufs2, &n_bufs2);
 	munit_assert_int(rv, ==, 0);
-	if (disk_mode) {
-		rv = fsm->snapshot_async(fsm, &bufs2, &n_bufs2);
-		munit_assert_int(rv, ==, 0);
-	}
 
-	rv = fsm->snapshot_finalize(fsm, &bufs2, &n_bufs2);
+	rv = fsm->snapshot_finalize(fsm, bufs2, n_bufs2);
 	munit_assert_int(rv, ==, 0);
 
 	return MUNIT_OK;
@@ -599,7 +379,6 @@ static MunitParameterEnum restore_params[] = {
     {"num_records", num_records},
     {SNAPSHOT_THRESHOLD_PARAM, snapshot_threshold},
     {SNAPSHOT_COMPRESSION_PARAM, bools},
-    {"disk_mode", bools},
     {NULL, NULL},
 };
 
@@ -619,12 +398,6 @@ TEST(fsm, snapshotRestore, setUp, tearDown, 0, restore_params)
 	int rv;
 	char sql[128];
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Add some data to database */
 	HANDSHAKE;
 	OPEN;
@@ -639,15 +412,10 @@ TEST(fsm, snapshotRestore, setUp, tearDown, 0, restore_params)
 	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
 	munit_assert_int(rv, ==, 0);
 
-	if (disk_mode) {
-		rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, ==, 0);
-	}
-
 	/* Deep copy snapshot */
 	snapshot = n_bufs_to_buf(bufs, n_bufs);
 
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
+	rv = fsm->snapshot_finalize(fsm, bufs, n_bufs);
 	munit_assert_int(rv, ==, 0);
 	clientClose(f->client);
 
@@ -692,12 +460,6 @@ TEST(fsm, snapshotRestoreMultipleDBs, setUp, tearDown, 0, snapshot_params)
 	char *msg;
 	int rv;
 
-	bool disk_mode = false;
-	const char *disk_mode_param = munit_parameters_get(params, "disk_mode");
-	if (disk_mode_param != NULL) {
-		disk_mode = (bool)atoi(disk_mode_param);
-	}
-
 	/* Create 2 databases and add data to them. */
 	HANDSHAKE;
 	OPEN_NAME("test");
@@ -718,14 +480,9 @@ TEST(fsm, snapshotRestoreMultipleDBs, setUp, tearDown, 0, snapshot_params)
 	rv = fsm->snapshot(fsm, &bufs, &n_bufs);
 	munit_assert_int(rv, ==, 0);
 
-	if (disk_mode) {
-		rv = fsm->snapshot_async(fsm, &bufs, &n_bufs);
-		munit_assert_int(rv, ==, 0);
-	}
-
 	/* Copy the snapshot to restore it */
 	snapshot = n_bufs_to_buf(bufs, n_bufs);
-	rv = fsm->snapshot_finalize(fsm, &bufs, &n_bufs);
+	rv = fsm->snapshot_finalize(fsm, bufs, n_bufs);
 	munit_assert_int(rv, ==, 0);
 
 	/* Create a new table in test2 that shouldn't be visible after
@@ -783,7 +540,6 @@ TEST(fsm, applyFail, setUp, tearDown, 0, NULL)
 	struct raft_buffer buf;
 	struct fixture *f = data;
 	struct raft_fsm *fsm = &f->servers[0].dqlite->raft_fsm;
-	void *result = (void *)(uintptr_t)0xDEADBEEF;
 
 	/* Create a frames command without data. */
 	c = (struct command_frames) {
@@ -797,9 +553,8 @@ TEST(fsm, applyFail, setUp, tearDown, 0, NULL)
 	rv = command__encode(COMMAND_FRAMES, &c, &buf);
 
 	/* Apply the command and expect it to fail. */
-	rv = fsm->apply(fsm, &buf, &result);
+	rv = fsm->apply(fsm, &buf);
 	munit_assert_int(rv, !=, 0);
-	munit_assert_ptr_null(result);
 
 	raft_free(buf.base);
 	return MUNIT_OK;
@@ -812,7 +567,6 @@ TEST(fsm, applyUnknownTypeFail, setUp, tearDown, 0, NULL)
 	struct raft_buffer buf;
 	struct fixture *f = data;
 	struct raft_fsm *fsm = &f->servers[0].dqlite->raft_fsm;
-	void *result = (void *)(uintptr_t)0xDEADBEEF;
 
 	/* Create a frames command without data. */
 	c = (struct command_frames) {
@@ -829,9 +583,8 @@ TEST(fsm, applyUnknownTypeFail, setUp, tearDown, 0, NULL)
 	((uint8_t *)(buf.base))[1] = COMMAND_CHECKPOINT + 8;
 
 	/* Apply the command and expect it to fail. */
-	rv = fsm->apply(fsm, &buf, &result);
+	rv = fsm->apply(fsm, &buf);
 	munit_assert_int(rv, ==, DQLITE_PROTO);
-	munit_assert_ptr_null(result);
 
 	raft_free(buf.base);
 	return MUNIT_OK;
