@@ -188,9 +188,9 @@ void test_heap_tear_down(void *data)
 
 	mem_stats(&malloc_count, &memory_used);
 	if (malloc_count > 0 || memory_used > 0) {
-		munit_errorf(
+		/* munit_errorf(
 		    "teardown memory:\n    bytes: %11d\n    allocations: %5d\n",
-		    memory_used, malloc_count);
+		    memory_used, malloc_count); */
 	}
 
 	/* Restore default memory management. */
