@@ -5,17 +5,18 @@
 #ifndef TEST_RAFT_H
 #define TEST_RAFT_H
 
-#include <raft.h>
-#include <raft/uv.h>
 #include <uv.h>
 
 #include "../../src/fsm.h"
+#include "../../src/raft.h"
 #include "../../src/transport.h"
 #include "fs.h"
 #include "logger.h"
 #include "munit.h"
 #include "uv.h"
 
+#include "../../src/lib/threadpool.h"
+
 #define FIXTURE_RAFT                             \
 	char *dir;                               \
 	struct uv_loop_s loop;                   \
