@@ -1,5 +1,5 @@
 #include "../../../src/raft.h"
-#include "../lib/runner.h"
+#include "../../lib/runner.h"
 
 SUITE(raft_digest)
 
