@@ -2,7 +2,7 @@
 #include "../../../src/raft/flags.h"
 #include "../../../src/raft/progress.h"
 #include "../lib/cluster.h"
-#include "../lib/runner.h"
+#include "../../lib/runner.h"
 
 /******************************************************************************
  *
