@@ -1,6 +1,6 @@
 #include <unistd.h>
 
-#include "../lib/runner.h"
+#include "../../lib/runner.h"
 #include "../lib/tcp.h"
 #include "../lib/uv.h"
 #include "append_helpers.h"
