@@ -1,5 +1,5 @@
 #include "../../../src/lib/queue.h"
-#include "../lib/runner.h"
+#include "../../lib/runner.h"
 
 /******************************************************************************
  *
