@@ -47,7 +47,6 @@ static void connCloseCb(struct conn *conn)
 
 #define SETUP                                                                \
 	struct uv_stream_s *stream;                                          \
-	struct id_state seed = { { 1 } };                                    \
 	int rv;                                                              \
 	SETUP_HEAP;                                                          \
 	SETUP_SQLITE;                                                        \
@@ -67,16 +66,16 @@ static void connCloseCb(struct conn *conn)
 	f->conn_test.closed = false;                                         \
 	rv = conn__start(&f->conn_test.conn, &f->config, &f->loop,           \
 			 &f->registry, &f->raft, stream, &f->raft_transport, \
-			 seed, connCloseCb);                                 \
+			 connCloseCb); \
 	munit_assert_int(rv, ==, 0)
 
 #define TEAR_DOWN                         \
 	pool_close(pool_ut_fallback());   \
-	pool_fini(pool_ut_fallback());    \
 	conn__stop(&f->conn_test.conn);   \
 	while (!f->conn_test.closed) {    \
 		test_uv_run(&f->loop, 1); \
 	};                                \
+	pool_fini(pool_ut_fallback());    \
 	TEAR_DOWN_RAFT;                   \
 	TEAR_DOWN_CLIENT;                 \
 	TEAR_DOWN_REGISTRY;               \
@@ -385,7 +384,7 @@ TEST_SETUP(query)
 	PREPARE_CONN("CREATE TABLE test (n INT)", &stmt_id);
 	EXEC_CONN(stmt_id, &f->last_insert_id, &f->rows_affected, 7);
 	PREPARE_CONN("INSERT INTO test(n) VALUES (123)", &f->insert_stmt_id);
-	EXEC_CONN(f->insert_stmt_id, &f->last_insert_id, &f->rows_affected, 4);
+	EXEC_CONN(f->insert_stmt_id, &f->last_insert_id, &f->rows_affected, 9);
 	return f;
 }
 
