@@ -1,3 +1,10 @@
+#ifndef _GNU_SOURCE
+# define _GNU_SOURCE
+#include <fcntl.h>
+#endif
+
+#include <stdlib.h>
+
 #include "../../include/dqlite.h"
 #include "../../src/gateway.h"
 #include "../../src/lib/threadpool.h"
@@ -8,6 +15,7 @@
 #include "../lib/raft_heap.h"
 #include "../lib/runner.h"
 
+
 TEST_MODULE(gateway);
 
 /******************************************************************************
@@ -54,7 +62,7 @@ struct connection {
 		struct connection *c = &f->connections[i];                  \
 		struct config *config;                                      \
 		config = CLUSTER_CONFIG(i);                                 \
-		config->page_size = 512;                                    \
+		config->vfs.page_size = 512;                                    \
 		gateway__init(&c->gateway, config, CLUSTER_REGISTRY(i),     \
 			      CLUSTER_RAFT(i));                                 \
 		c->handle.data = &c->context;                               \
@@ -86,6 +94,38 @@ struct connection {
 	}                                                  \
 	TEAR_DOWN_CLUSTER;
 
+#define INTEGRITY_CHECK(file)                                                 \
+	do {                                                                  \
+		char path[PATH_MAX] = {};                                     \
+		snprintf(path, PATH_MAX, "%s/%s", f->temp_dir, (file).name);  \
+		int fd = open(path, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR);     \
+		munit_assert_int(fd, >, 0);                                   \
+		ssize_t write_rv =                                            \
+		    write(fd, (file).content.base, (file).content.len);       \
+		munit_assert_int(write_rv, ==, (file).content.len);           \
+		sqlite3 *conn;                                                \
+		int sqlite_rv =                                               \
+		    sqlite3_open_v2(path, &conn, SQLITE_OPEN_READONLY, NULL); \
+		munit_assert_int(sqlite_rv, ==, SQLITE_OK);                   \
+		sqlite_rv = sqlite3_exec(conn, "PRAGMA integrity_check",      \
+					 integrityCheckCb, NULL, NULL);       \
+		munit_assert_int(sqlite_rv, ==, SQLITE_OK);                   \
+		sqlite3_close(conn);                                          \
+		close(fd);                                                    \
+	} while (0)
+
+static int integrityCheckCb(void *ctx, int n, char **values, char **names) {
+	munit_assert_null(ctx);
+	munit_assert_int(n, ==, 1);
+	munit_assert_string_equal(names[0], "integrity_check");
+
+	if (sqlite3_stricmp(values[0], "ok") != 0) {
+		munit_errorf("integrity fail: %s", values[0]);
+	}
+
+	return SQLITE_OK;
+}
+
 static void closeCb(struct gateway *g) {
 	struct connection *c = CONTAINER_OF(g, struct connection, gateway);
 	c->context.invoked = true;
@@ -588,6 +628,13 @@ TEST_CASE(prepare, barrier_error, NULL)
 	raft_fixture_append_fault(&f->cluster, 0, 0);
 	int rv = raft_barrier(CLUSTER_RAFT(0), &faulty_barrier, barrierCb);
 	munit_assert_int(rv, ==, 0);
+	
+	/* Make sure all databases require reading the last index. */
+	queue *item;
+	QUEUE_FOREACH(item, &f->servers[0].registry.dbs) {
+		struct db *db = QUEUE_DATA(item, struct db, queue);
+		db->read_index = faulty_barrier.index;
+	}
 
 	f->request.db_id = 0;
 	f->request.sql = "SELECT 1";
@@ -1258,6 +1305,13 @@ TEST_CASE(exec, barrier_error, NULL)
 	int rv = raft_barrier(CLUSTER_RAFT(0), &faulty_barrier, barrierCb);
 	munit_assert_int(rv, ==, 0);
 
+	/* Make sure all databases require reading the last index. */
+	queue *item;
+	QUEUE_FOREACH(item, &f->servers[0].registry.dbs) {
+		struct db *db = QUEUE_DATA(item, struct db, queue);
+		db->read_index = faulty_barrier.index;
+	}
+
 	f->request.db_id = 0;
 	f->request.stmt_id = stmt_id;
 	ENCODE(&f->request, exec);
@@ -1705,7 +1759,8 @@ TEST_CASE(query, returning_interrupt, NULL)
 	/* Query 2 response buffers worth of rows */
 	/* 16 = 8B header + 8B value (int) */
 	int64_t n_rows_buffer = max_rows_buffer(16);
-	struct value n_rows = { .type = SQLITE_INTEGER, .integer = n_rows_buffer*2-1 };
+	int64_t n_rows = n_rows_buffer * 2 - 1;
+	struct value n_rows_value = { .type = SQLITE_INTEGER, .integer = n_rows };
 
 	PREPARE("WITH RECURSIVE seq(n) AS ("
             "	SELECT 1               "
@@ -1717,7 +1772,7 @@ TEST_CASE(query, returning_interrupt, NULL)
 	f->request.db_id = 0;
 	f->request.stmt_id = stmt_id;
 	ENCODE(&f->request, query);
-	ENCODE_PARAMS(1, &n_rows, TUPLE__PARAMS);
+	ENCODE_PARAMS(1, &n_rows_value, TUPLE__PARAMS);
 	HANDLE(QUERY);
 	WAIT;
 	ASSERT_CALLBACK(0, ROWS);
@@ -1744,14 +1799,24 @@ TEST_CASE(query, returning_interrupt, NULL)
 	munit_assert_false(f->context->invoked);
 	gateway__resume(f->gateway, &finished);
 	munit_assert_false(finished);
+	WAIT;
 	ASSERT_CALLBACK(0, EMPTY);
 
-	/* Make sure rows are not there. */
-	PREPARE("SELECT * FROM test");
+	/* Make sure all rows are there. */
+	PREPARE("SELECT COUNT(*) FROM test");
+	f->request.db_id = 0;
+	f->request.stmt_id = stmt_id;
 	ENCODE(&f->request, query);
 	HANDLE(QUERY);
 	WAIT;
-	ASSERT_CALLBACK(0, EMPTY);
+	ASSERT_CALLBACK(0, ROWS);
+	uint64__decode(f->cursor, &n);
+	munit_assert_int(n, ==, 1);
+	text__decode(f->cursor, &column);
+	munit_assert_string_equal(column, "COUNT(*)");
+	DECODE_ROW(1, &value);
+	munit_assert_int(value.type, ==, SQLITE_INTEGER);
+	munit_assert_int(value.integer, ==, n_rows);
 
 	return MUNIT_OK;
 }
@@ -1949,6 +2014,13 @@ TEST_CASE(query, barrier_error, NULL)
 	int rv = raft_barrier(CLUSTER_RAFT(0), &faulty_barrier, barrierCb);
 	munit_assert_int(rv, ==, 0);
 
+	/* Make sure all databases require reading the last index. */
+	queue *item;
+	QUEUE_FOREACH(item, &f->servers[0].registry.dbs) {
+		struct db *db = QUEUE_DATA(item, struct db, queue);
+		db->read_index = faulty_barrier.index;
+	}
+
 	f->request.db_id = 0;
 	f->request.stmt_id = stmt_id;
 	ENCODE(&f->request, query);
@@ -2300,6 +2372,13 @@ TEST_CASE(exec_sql, barrier_error, NULL)
 	int rv = raft_barrier(CLUSTER_RAFT(0), &faulty_barrier, barrierCb);
 	munit_assert_int(rv, ==, 0);
 
+	/* Make sure all databases require reading the last index. */
+	queue *item;
+	QUEUE_FOREACH(item, &f->servers[0].registry.dbs) {
+		struct db *db = QUEUE_DATA(item, struct db, queue);
+		db->read_index = faulty_barrier.index;
+	}
+
 	f->request.db_id = 0;
 	f->request.sql = "CREATE TABLE test (n INT)";
 	ENCODE(&f->request, exec_sql);
@@ -2773,7 +2852,8 @@ TEST_CASE(query_sql, returning_interrupt, NULL)
 	/* Query 2 response buffers worth of rows */
 	/* 16 = 8B header + 8B value (int) */
 	int64_t n_rows_buffer = max_rows_buffer(16);
-	struct value n_rows = { .type = SQLITE_INTEGER, .integer = n_rows_buffer*2-1 };
+	int64_t n_rows = n_rows_buffer * 2 - 1;
+	struct value n_rows_value = { .type = SQLITE_INTEGER, .integer = n_rows };
 
 	f->request.db_id = 0;
 	f->request.sql = 
@@ -2785,7 +2865,7 @@ TEST_CASE(query_sql, returning_interrupt, NULL)
 		")                         "
 		"INSERT INTO test(n) SELECT n FROM seq RETURNING n";
 	ENCODE(&f->request, query_sql);
-	ENCODE_PARAMS(1, &n_rows, TUPLE__PARAMS);
+	ENCODE_PARAMS(1, &n_rows_value, TUPLE__PARAMS);
 	HANDLE(QUERY_SQL);
 	WAIT;
 	ASSERT_CALLBACK(0, ROWS);
@@ -2812,14 +2892,22 @@ TEST_CASE(query_sql, returning_interrupt, NULL)
 	munit_assert_false(f->context->invoked);
 	gateway__resume(f->gateway, &finished);
 	munit_assert_false(finished);
+	WAIT;
 	ASSERT_CALLBACK(0, EMPTY);
 
-	/* Make sure rows are not there. */
-	f->request.sql = "SELECT * FROM test";
+	/* Make sure all rows are there. */
+	f->request.sql = "SELECT COUNT(*) FROM test";
 	ENCODE(&f->request, query_sql);
 	HANDLE(QUERY_SQL);
 	WAIT;
-	ASSERT_CALLBACK(0, EMPTY);
+	ASSERT_CALLBACK(0, ROWS);
+	uint64__decode(f->cursor, &n);
+	munit_assert_int(n, ==, 1);
+	text__decode(f->cursor, &column);
+	munit_assert_string_equal(column, "COUNT(*)");
+	DECODE_ROW(1, &value);
+	munit_assert_int(value.type, ==, SQLITE_INTEGER);
+	munit_assert_int(value.integer, ==, n_rows);
 
 	return MUNIT_OK;
 }
@@ -2961,6 +3049,13 @@ TEST_CASE(query_sql, barrier_error, NULL)
 	int rv = raft_barrier(CLUSTER_RAFT(0), &faulty_barrier, barrierCb);
 	munit_assert_int(rv, ==, 0);
 
+	/* Make sure all databases require reading the last index. */
+	queue *item;
+	QUEUE_FOREACH(item, &f->servers[0].registry.dbs) {
+		struct db *db = QUEUE_DATA(item, struct db, queue);
+		db->read_index = faulty_barrier.index;
+	}
+
 	f->request.db_id = 0;
 	f->request.sql = "SELECT n FROM test";
 	ENCODE(&f->request, query_sql);
@@ -3084,6 +3179,7 @@ struct request_dump_fixture {
 	FIXTURE;
 	struct request_dump request;
 	struct response_files response;
+	char *temp_dir;
 };
 
 TEST_SUITE(dump);
@@ -3092,12 +3188,14 @@ TEST_SETUP(dump)
 	struct request_dump_fixture *f = munit_malloc(sizeof *f);
 	SETUP;
 	CLUSTER_ELECT(0);
+	f->temp_dir = test_dir_setup();
 	return f;
 }
 TEST_TEAR_DOWN(dump)
 {
 	struct request_dump_fixture *f = data;
 	TEAR_DOWN;
+	test_dir_tear_down(f->temp_dir);
 	free(f);
 }
 
@@ -3105,6 +3203,8 @@ TEST_CASE(dump, empty, NULL)
 {
 	(void)params;
 	struct request_dump_fixture *f = data;
+	OPEN;
+	
 	f->request = (struct request_dump){
 		.filename = "test",
 	};
@@ -3117,14 +3217,16 @@ TEST_CASE(dump, empty, NULL)
 	struct file main = {};
 	DECODE_FILE(&main);
 	munit_assert_string_equal(main.name, "test");
-	munit_assert_int(main.content.len, ==, 0);
+	munit_assert_int(main.content.len, ==, 512);
 
 	struct file wal = {};
 	DECODE_FILE(&wal);
 	munit_assert_string_equal(wal.name, "test-wal");
 	munit_assert_int(wal.content.len, ==, 0);
-
 	munit_assert_int(f->cursor->cap, ==, 0);
+
+	INTEGRITY_CHECK(main);
+
 	return MUNIT_OK;
 }
 
@@ -3137,21 +3239,8 @@ TEST_CASE(dump, not_existent, NULL)
 	};
 	ENCODE(&f->request, dump);
 	HANDLE(DUMP);
-	ASSERT_CALLBACK(DQLITE_OK, FILES);
-	DECODE(&f->response, files);
-
-	munit_assert_int(f->response.n, ==, 2);
-	struct file main = {};
-	DECODE_FILE(&main);
-	munit_assert_string_equal(main.name, "foo");
-	munit_assert_int(main.content.len, ==, 0);
-
-	struct file wal = {};
-	DECODE_FILE(&wal);
-	munit_assert_string_equal(wal.name, "foo-wal");
-	munit_assert_int(wal.content.len, ==, 0);
-
-	munit_assert_int(f->cursor->cap, ==, 0);
+	ASSERT_CALLBACK(DQLITE_NOTFOUND, FAILURE);
+	ASSERT_FAILURE(DQLITE_NOTFOUND, "database does not exists");
 
 	return MUNIT_OK;
 }
@@ -3182,9 +3271,11 @@ TEST_CASE(dump, simple, NULL)
 	struct file wal = {};
 	DECODE_FILE(&wal);
 	munit_assert_string_equal(wal.name, "test-wal");
-	munit_assert_int(wal.content.len, >, 0);
-
+	munit_assert_int(wal.content.len, ==, 0);
 	munit_assert_int(f->cursor->cap, ==, 0);
+
+	INTEGRITY_CHECK(main);
+
 	return MUNIT_OK;
 }
 
@@ -3216,9 +3307,12 @@ TEST_CASE(dump, simple_follower, NULL)
 	struct file wal = {};
 	DECODE_FILE(&wal);
 	munit_assert_string_equal(wal.name, "test-wal");
-	munit_assert_int(wal.content.len, >, 0);
+	munit_assert_int(wal.content.len, ==, 0);
 
 	munit_assert_int(f->cursor->cap, ==, 0);
+
+	INTEGRITY_CHECK(main);
+
 	return MUNIT_OK;
 }
 
@@ -3234,7 +3328,7 @@ TEST_CASE(dump, checkpointed, NULL)
 	struct config *config = f->gateway->config;
 	struct value blobsize = {
 		.type = SQLITE_INTEGER,
-		.integer = config->page_size * config->checkpoint_threshold,
+		.integer = config->vfs.page_size * config->vfs.checkpoint_threshold,
 	};
 	PREPARE(
 	    "INSERT INTO test           "
@@ -3268,7 +3362,7 @@ TEST_CASE(dump, checkpointed, NULL)
 	DECODE_FILE(&main);
 	munit_assert_string_equal(main.name, "test");
 	munit_assert_int(main.content.len, >=,
-			 config->checkpoint_threshold * config->page_size);
+			 config->vfs.checkpoint_threshold * config->vfs.page_size);
 
 	struct file wal = {};
 	DECODE_FILE(&wal);
@@ -3276,6 +3370,9 @@ TEST_CASE(dump, checkpointed, NULL)
 	munit_assert_int(wal.content.len, ==, 0);
 
 	munit_assert_int(f->cursor->cap, ==, 0);
+
+	INTEGRITY_CHECK(main);
+
 	return MUNIT_OK;
 }
 
@@ -3317,3 +3414,83 @@ TEST_CASE(invalid, requestType, NULL)
 	ASSERT_FAILURE(DQLITE_PARSE, "unrecognized request type");
 	return MUNIT_OK;
 }
+
+/******************************************************************************
+ *
+ * transfer
+ *
+ ******************************************************************************/
+
+struct transfer_fixture {
+	FIXTURE;
+};
+
+TEST_SUITE(transfer);
+TEST_SETUP(transfer)
+{
+	struct transfer_fixture *f = munit_malloc(sizeof *f);
+	SETUP;
+	CLUSTER_ELECT(0);
+	return f;
+}
+TEST_TEAR_DOWN(transfer)
+{
+	struct transfer_fixture *f = data;
+	TEAR_DOWN;
+	free(f);
+}
+
+TEST_CASE(transfer, any, NULL)
+{
+	(void)params;
+	struct transfer_fixture *f = data;
+	const raft_id initial_leader = f->cluster.leader_id;
+
+	struct request_transfer request = {
+		.id = 0,
+	};
+	ENCODE(&request, transfer);
+	HANDLE(TRANSFER);
+	WAIT;
+	ASSERT_CALLBACK(DQLITE_OK, EMPTY);
+
+	raft_fixture_step_until_has_leader(&f->cluster, 20000);
+
+	/* Make sure there's a leader. */
+	munit_assert_int(f->cluster.leader_id, !=, 0);
+	/* Make sure the leader changed. */
+	munit_assert_int(f->cluster.leader_id, !=, initial_leader);
+
+	return MUNIT_OK;
+}
+
+TEST_CASE(transfer, target, NULL)
+{
+	(void)params;
+	struct transfer_fixture *f = data;
+	const raft_id initial_leader = f->cluster.leader_id;
+
+	struct request_transfer request = {};
+	for (unsigned i = 0; i < N_SERVERS; i++) {
+		const struct raft *r = raft_fixture_get(&f->cluster, i);
+		if (r->id == initial_leader) {
+			continue;
+		}
+		request.id = r->id;
+	}
+	munit_assert_int(request.id, !=, 0);
+
+	ENCODE(&request, transfer);
+	HANDLE(TRANSFER);
+	WAIT;
+	ASSERT_CALLBACK(DQLITE_OK, EMPTY);
+
+	raft_fixture_step_until_has_leader(&f->cluster, 20000);
+
+	/* Make sure there's a leader. */
+	munit_assert_int(f->cluster.leader_id, !=, 0);
+	/* Make sure the leader changed. */
+	munit_assert_int(f->cluster.leader_id, !=, initial_leader);
+
+	return MUNIT_OK;
+}
